#!/bin/bash
#
# Put deb/rpm package into APT/YUM repository
#

set -e
set -u

USAGE="
  This script puts binary packages into APT/YUM repository.

  Usage:

   $0 --dist <dist> pkg1 pkg2 pkg3 ...

      <dist>  is distribution name: squeeze, wheezy, lucid, precise, trusty

"


DEBIAN_APT_REPO_DIR="/home/alex/Public/packages/debian"
UBUNTU_APT_REPO_DIR="/home/alex/Public/packages/ubuntu"
GPG_KEY_ID="4823E840"


# parse options
dist=
while getopts d: name
do
  case $name in
  d)
       dist="$OPTARG";;
  ?)   printf "Usage: %s: -d <dist> pkg1 pkg2 ...\n" $0
        exit 2;;
  esac
done

if [ -z "$dist" ]; then
  printf 'Option -d is required\n'
  exit 2
fi
shift $(($OPTIND - 1))
PKGS="$*"


# Create 'reprepro' config for specified distribution
#
make_config()
{
  local cnf="$1/conf/distributions"
  test -e "$cnf" || { mkdir -p "$1/conf" ; touch "$cnf" ; }
  if ! cat $cnf | grep -q "^Codename: $dist" ; then
cat << EOF >> "$cnf"

Origin: packages.jetico.com
Label: apt repository
Codename: $dist
Architectures: i386 amd64
Components: non-free
Description: Jetico, Oy products repository
SignWith: $GPG_KEY_ID
Pull: $dist

EOF
  fi
}

case $dist in
  squeeze|wheezy|testing)
    # debian family
    REPO_TYPE="deb"
    REPO_DIR="$DEBIAN_APT_REPO_DIR"
    SECTION="non-free"
    ;;
  lucid|raring|saucy|precise|trusty)
    # ubuntu family
    REPO_TYPE="deb"
    REPO_DIR="$UBUNTU_APT_REPO_DIR"
    SECTION="multiverse"
    ;;
  *)
    echo "Error: unknown distribution name: $dist"
    exit 1
esac


case $REPO_TYPE in
  deb)
    make_config $REPO_DIR $dist $SECTION
    reprepro --verbose --basedir ${REPO_DIR} --section $SECTION includedeb $dist ${PKGS}
    ;;
  *)
    echo "Repository type for upload is undefined"
esac
